"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.junit = void 0;
const path_1 = require("@stoplight/path");
const lodash_1 = require("lodash");
const utils_1 = require("../../utils");
const utils_2 = require("./utils");
exports.junit = (results, { failSeverity }) => {
    var _a;
    let output = '';
    output += '<?xml version="1.0" encoding="utf-8"?>\n';
    output += '<testsuites>\n';
    const groupedResults = utils_2.groupBySource(results);
    for (const [source, validationResults] of Object.entries(groupedResults)) {
        const classname = source.replace(new RegExp(`${lodash_1.escapeRegExp(path_1.extname(source))}$`), '');
        if (validationResults.length > 0) {
            const filteredValidationResults = validationResults.filter(result => result.severity <= failSeverity);
            output += `<testsuite package="org.spectral" time="0" tests="${filteredValidationResults.length}" errors="0" failures="${filteredValidationResults.length}" name="${source}">\n`;
            for (const result of filteredValidationResults) {
                output += `<testcase time="0" name="org.spectral.${(_a = result.code) !== null && _a !== void 0 ? _a : 'unknown'}" classname="${classname}">`;
                output += `<failure message="${utils_2.xmlEscape(result.message)}">`;
                output += '<![CDATA[';
                output += `line ${result.range.start.line + 1}, col ${result.range.start.character + 1}, `;
                output += `${utils_2.xmlEscape(result.message)} (${result.code}) `;
                output += `at path ${utils_2.xmlEscape(utils_1.printPath(result.path, utils_1.PrintStyle.EscapedPointer))}`;
                output += ']]>';
                output += `</failure>`;
                output += '</testcase>\n';
            }
            output += '</testsuite>\n';
        }
        else {
            output += `<testsuite package="org.spectral" time="0" tests="1" errors="0" name="${source}">\n`;
            output += `<testcase time="0" name="${source}" classname="${classname}" />\n`;
            output += '</testsuite>\n';
        }
    }
    output += '</testsuites>\n';
    return output;
};
//# sourceMappingURL=junit.js.map