"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.readParsable = exports.readFile = void 0;
const path_1 = require("@stoplight/path");
const abort_controller_1 = require("abort-controller");
const fs = require("fs");
const assets_1 = require("../assets");
const request_1 = require("../request");
async function readFile(name, opts) {
    if (typeof name === 'number') {
        let result = '';
        const stream = fs.createReadStream('', { fd: name });
        stream.setEncoding(opts.encoding);
        stream.on('readable', () => {
            let chunk;
            while ((chunk = stream.read()) !== null) {
                result += chunk;
            }
        });
        return new Promise((resolve, reject) => {
            stream.on('error', reject);
            stream.on('end', () => {
                resolve(result);
            });
        });
    }
    else if (name in assets_1.STATIC_ASSETS) {
        return assets_1.STATIC_ASSETS[name];
    }
    else if (path_1.isURL(name)) {
        let response;
        let timeout = null;
        try {
            const requestOpts = {};
            requestOpts.agent = opts.agent;
            if (opts.timeout) {
                const controller = new abort_controller_1.default();
                timeout = setTimeout(() => {
                    controller.abort();
                }, opts.timeout);
                requestOpts.signal = controller.signal;
            }
            response = await request_1.default(name, requestOpts);
            if (!response.ok)
                throw new Error(response.statusText);
            return await response.text();
        }
        catch (ex) {
            if (ex.name === 'AbortError') {
                throw new Error('Timeout');
            }
            else {
                throw ex;
            }
        }
        finally {
            if (timeout !== null) {
                clearTimeout(timeout);
            }
        }
    }
    else {
        try {
            return await new Promise((resolve, reject) => {
                fs.readFile(name, opts.encoding, (err, data) => {
                    if (err !== null) {
                        reject(err);
                    }
                    else {
                        resolve(data);
                    }
                });
            });
        }
        catch (ex) {
            throw new Error(`Could not read ${name}: ${ex.message}`);
        }
    }
}
exports.readFile = readFile;
async function readParsable(name, opts) {
    try {
        return await readFile(name, opts);
    }
    catch (ex) {
        throw new Error(`Could not parse ${name}: ${ex.message}`);
    }
}
exports.readParsable = readParsable;
//# sourceMappingURL=reader.js.map