"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mergeFunctions = void 0;
const nanoid = require("nanoid/non-secure");
function mergeFunctions(target, source, rules) {
    const map = {};
    for (const [name, def] of Object.entries(source)) {
        const newName = nanoid();
        map[name] = newName;
        target[newName] = def;
        target[name] = {
            name: def.name,
            schema: def.schema,
            ref: newName,
            source: def.source,
        };
    }
    for (const rule of Object.values(rules)) {
        if (typeof rule === 'object') {
            const ruleThen = Array.isArray(rule.then) ? rule.then : [rule.then];
            for (const then of ruleThen) {
                if (then.function in map) {
                    then.function = map[then.function];
                }
            }
        }
    }
}
exports.mergeFunctions = mergeFunctions;
//# sourceMappingURL=functions.js.map