"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getLintTargets = void 0;
const jsonpath_plus_1 = require("jsonpath-plus");
const lodash_1 = require("lodash");
const { toPathArray } = jsonpath_plus_1.JSONPath;
exports.getLintTargets = (targetValue, field) => {
    const targets = [];
    if (lodash_1.isObject(targetValue) && typeof field === 'string') {
        if (field === '@key') {
            for (const key of Object.keys(targetValue)) {
                targets.push({
                    path: [key],
                    value: key,
                });
            }
        }
        else if (field.startsWith('$')) {
            jsonpath_plus_1.JSONPath({
                path: field,
                json: targetValue,
                resultType: 'all',
                callback(result) {
                    targets.push({
                        path: toPathArray(result.path).slice(1),
                        value: result.value,
                    });
                },
            });
        }
        else {
            targets.push({
                path: lodash_1.toPath(field),
                value: lodash_1.get(targetValue, field),
            });
        }
    }
    else {
        targets.push({
            path: [],
            value: targetValue,
        });
    }
    if (targets.length === 0) {
        targets.push({
            path: [],
            value: void 0,
        });
    }
    return targets;
};
//# sourceMappingURL=getLintTargets.js.map