"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.prepareResults = exports.defaultComputeResultFingerprint = void 0;
const md5 = require('blueimp-md5');
const lodash_1 = require("lodash");
const sortResults_1 = require("./sortResults");
exports.defaultComputeResultFingerprint = (rule, hash) => {
    let id = String(rule.code);
    if (rule.path.length > 0) {
        id += JSON.stringify(rule.path);
    }
    else {
        id += JSON.stringify(rule.range);
    }
    if (rule.source !== void 0) {
        id += rule.source;
    }
    return hash(id);
};
exports.prepareResults = (results, computeFingerprint) => {
    decorateResultsWithFingerprint(results, computeFingerprint);
    return sortResults(deduplicateResults(results));
};
const decorateResultsWithFingerprint = (results, computeFingerprint) => {
    for (const r of results) {
        Object.defineProperty(r, 'fingerprint', {
            value: computeFingerprint(r, md5),
        });
    }
    return results;
};
const deduplicateResults = (results) => {
    return lodash_1.uniqBy([...results], 'fingerprint');
};
const sortResults = (results) => {
    return [...results].sort(sortResults_1.compareResults);
};
//# sourceMappingURL=prepareResults.js.map